==> owncloud-10.0.7.tgz: owncloud/apps/federatedfilesharing/l10n/ja.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "サーバー連携共有",
    "Invalid Federated Cloud ID" : "クラウド連携IDが無効です",
    "Sharing %s failed, because this item is already shared with %s" : "%s を共有できませんでした。このアイテムはすでに %s に共有されています。",
    "Not allowed to create a federated share with the same user" : "同じユーザーではサーバー連携共有は作成できません",
    "File is already shared with %s" : "ファイルはすでに %s と共有されています。",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s を共有できませんでした。%s が見つかりませんでした。現在サーバーに接続できないようです。",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "%1$s からリモート共有として \"/%3$s\" を受け取りました。(%2$s の代理として)",
    "You received \"/%3$s\" as a remote share from %1$s" : "%1$s からリモート共有として \"/%3$s\" を受け取りました。",
    "Accept" : "受領",
    "Decline" : "拒否",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "#ownCloud の「クラウド連携ID」で私と共有できます。こちらを見てください。%s",
    "Share with me through my #ownCloud Federated Cloud ID" : "#ownCloud の「クラウド連携ID」で私と共有できます。",
    "Federated Cloud Sharing" : "クラウド連携共有",
    "Open documentation" : "ドキュメントを開く",
    "Allow users on this server to send shares to other servers" : "ユーザーがこのサーバーから他のサーバーに共有することを許可する",
    "Allow users on this server to receive shares from other servers" : "ユーザーが他のサーバーからこのサーバーに共有することを許可する",
    "Federated Cloud" : "クラウド連携",
    "Your Federated Cloud ID:" : "あなたのクラウド連携ID：",
    "Share it:" : "以下で共有:",
    "Add to your website" : "ウェブサイトに追加",
    "Share with me via ownCloud" : "OwnCloud経由で共有",
    "HTML Code:" : "HTMLコード:"
},
"nplurals=1; plural=0;");

==> owncloud-10.0.10.tgz: owncloud/apps/federatedfilesharing/l10n/ja.js <==
OC.L10N.register(
    "federatedfilesharing",
    {
    "Federated sharing" : "サーバー連携共有",
    "Invalid Federated Cloud ID" : "クラウド連携IDが無効です",
    "Sharing %s failed, because this item is already shared with %s" : "%s を共有できませんでした。このアイテムはすでに %s に共有されています。",
    "Not allowed to create a federated share with the same user" : "同じユーザーではサーバー連携共有は作成できません",
    "File is already shared with %s" : "ファイルはすでに %s と共有されています。",
    "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "%s を共有できませんでした。%s が見つかりませんでした。現在サーバーに接続できないようです。",
    "You received \"/%3$s\" as a remote share from %1$s (on behalf of %2$s)" : "%1$s からリモート共有として \"/%3$s\" を受け取りました。(%2$s の代理として)",
    "You received \"/%3$s\" as a remote share from %1$s" : "%1$s からリモート共有として \"/%3$s\" を受け取りました。",
    "Accept" : "受領",
    "Decline" : "拒否",
    "Share with me through my #ownCloud Federated Cloud ID, see %s" : "#ownCloud の「クラウド連携ID」で私と共有できます。こちらを見てください。%s",
    "Share with me through my #ownCloud Federated Cloud ID" : "#ownCloud の「クラウド連携ID」で私と共有できます。",
    "Federated Cloud Sharing" : "クラウド連携共有",
    "Open documentation" : "ドキュメントを開く",
    "Allow users on this server to send shares to other servers" : "ユーザーがこのサーバーから他のサーバーに共有することを許可する",
    "Allow users on this server to receive shares from other servers" : "ユーザーが他のサーバーからこのサーバーに共有することを許可する",
    "Federated Cloud" : "クラウド連携",
    "Your Federated Cloud ID:" : "あなたのクラウド連携ID：",
    "Share it:" : "以下で共有:",
    "Add to your website" : "ウェブサイトに追加",
    "Share with me via ownCloud" : "OwnCloud経由で共有",
    "HTML Code:" : "HTMLコード:",
    "Add to your ownCloud" : "ownCloud に追加"
},
"nplurals=1; plural=0;");
